pub struct AgentTelemetryTraceExportSettings {
pub enabled: bool,
pub protocol: AgentTelemetryTraceExportProtocol,
pub endpoint: String,
}Expand description
OTLP trace export settings for request-level agent telemetry.
Fields
enabled: boolExport tracing spans to a local or remote OTLP collector.
protocol: AgentTelemetryTraceExportProtocolOTLP transport protocol used when exporting spans.
endpoint: StringOTLP collector endpoint for the selected protocol.
Implementations
Sourceimpl AgentTelemetryTraceExportSettings
impl AgentTelemetryTraceExportSettings
Sourcepub fn normalize_endpoint(&mut self)
pub fn normalize_endpoint(&mut self)
Normalizes the endpoint when it is empty or still set to the stock default for the wrong transport.