pub struct LlmSettings {
pub primary: String,
pub fallback: Option<String>,
pub openai: Option<OpenAiConfig>,
pub anthropic: Option<AnthropicConfig>,
pub gemini: Option<GeminiConfig>,
pub grok: Option<GrokConfig>,
pub ollama: Option<OllamaConfig>,
}Expand description
LLM settings grouping provider-specific configs
Fields
primary: StringPrimary provider id: “openai” | “anthropic” | “gemini” | “grok” | “ollama”
fallback: Option<String>Fallback provider id (optional): used when primary fails
openai: Option<OpenAiConfig>anthropic: Option<AnthropicConfig>gemini: Option<GeminiConfig>grok: Option<GrokConfig>ollama: Option<OllamaConfig>Implementations
Sourceimpl LlmSettings
impl LlmSettings
Sourcepub fn ensure_provider_config(&mut self, provider: &str)
pub fn ensure_provider_config(&mut self, provider: &str)
Ensure the provider-specific config object for provider exists and has a
non-empty model field. If the config object is missing it is created with
Default::default() (which now includes the correct default model). If the
config already exists but has an empty model, the model is back-filled.